@@ -3,23 +3,48 @@ import glob
 import os
 from distutils.util import strtobool
 
-from interfaces import parsing_face, parsing_faces
+
 import filetype
 from tqdm import tqdm
 
 import sys 
 sys.path.append("..") 
+directory = os.getcwd()
+print(directory)
+# from interfaces import parsing_face, parsing_faces
 from model import BiSeNet
 
 
+def parsing_face(net, image):
+    import io
+    to_tensor = transforms.Compose([
+        transforms.ToTensor(),
+        transforms.Normalize((0.485, 0.456, 0.406), (0.229, 0.224, 0.225)),
+    ])
+    # img=Image.open(input_path)
+    image = input_img.resize((512, 512), Image.BILINEAR)
+    img = to_tensor(image)
+    img = torch.unsqueeze(img, 0)
+    img = img.cuda()
+    with torch.no_grad():
+        out = net(img)[0]
+    parsing = out.squeeze(0).cpu().numpy().argmax(0)
+
+    vis_parsing_anno, vis_im = vis_parsing_maps(image, parsing, stride=1, save_im=False)
+    bio = io.BytesIO()
+    vis_im.save(bio, "PNG")
+
+    return bio.getbuffer()
+
+
 @parsing.command()
 @parsing.argument('in_path')
 @parsing.argument('out_path')
 def main(in_path, out_path):
-    # model_path = os.environ.get(
-    #     "U2NETP_PATH",
-    #     os.path.expanduser(os.path.join("~", ".u2net")),
-    # )
+    model_path = os.environ.get(
+        "U2NETP_PATH",
+        os.path.expanduser(os.path.join("~", ".u2net")),
+    )
     model_path='../.cache/face_parsing/79999_iter.pth'
     model=BiSeNet()
     model.load_state_dict(torch.load(model_path))
